"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const HttpException_1 = __importDefault(require("./HttpException"));
const http_status_1 = __importDefault(require("../utils/http-status"));
// Storing the status code and Default message for the BadRequestException
const statusCode = http_status_1.default.BAD_REQUEST;
const defaultMessage = `${statusCode} Bad request`;
/**
 * Custom BadRequestException class extending HttpException.
 * This exception is used to represent HTTP 400 Bad Request errors.
 */
class BadRequestException extends HttpException_1.default {
    /**
     * Constructor for the BadRequestException class.
     *
     * @param {string} message - The error message for the exception (default: defaultMessage).
     * @param {object | undefined} properties - Additional properties for the exception (optional).
     */
    constructor(message = defaultMessage, properties) {
        // Calling the constructor of the parent class (HttpException)
        super(statusCode, message, properties);
        // Setting the name of the exception
        this.name = 'BadRequestException';
    }
}
exports.default = BadRequestException;
