"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const HttpException_1 = __importDefault(require("./HttpException"));
const http_status_1 = __importDefault(require("../utils/http-status"));
// Storing the status code and Default message for the ConflictException
const statusCode = http_status_1.default.CONFLICT;
const defaultMessage = `${statusCode} Conflict`;
/**
 * Custom ConflictException class extending HttpException.
 * This exception is used to represent HTTP 409 Conflict errors.
 */
class ConflictException extends HttpException_1.default {
    /**
     * Constructor for the ConflictException class.
     * @param message - The error message (default is the predefined message).
     * @param properties - Additional properties to include in the error response.
     */
    constructor(message = defaultMessage, properties) {
        // Calling the constructor of the parent class (HttpException)
        super(statusCode, message, properties);
        // Setting the name of the exception
        this.name = 'ConflictException';
    }
}
exports.default = ConflictException;
