"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const HttpException_1 = __importDefault(require("./HttpException"));
const http_status_1 = __importDefault(require("../utils/http-status"));
// Storing the status code and Default message for the ForbiddenException
const statusCode = http_status_1.default.FORBIDDEN;
const defaultMessage = `${statusCode} Forbidden`;
/**
 * Custom ForbiddenException class extending HttpException.
 * This exception is used to represent HTTP 403 Forbidden errors.
 */
class ForbiddenException extends HttpException_1.default {
    /**
     * Constructor for ForbiddenException.
     * @param {string} message - The error message for the exception. Default is defaultMessage.
     * @param {object | undefined} properties - Additional properties to include in the exception.
     */
    constructor(message = defaultMessage, properties) {
        // Call the constructor of the base class (HttpException)
        super(statusCode, message, properties);
        // Set the name of the exception
        this.name = 'ForbiddenException';
    }
}
exports.default = ForbiddenException;
