"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * HTTP exception class
 */
class HttpException extends Error {
    // HTTP status code for the exception
    statusCode;
    // Additional properties associated with the exception
    properties;
    /**
     * Creates an instance of the HttpException class.
     *
     * @param {number} statusCode - HTTP status code
     * @param {string} message - error message
     * @param {object} properties - Additional properties
     */
    constructor(statusCode, message, properties) {
        super(message);
        this.statusCode = statusCode;
        this.name = 'HttpException';
        if (typeof properties === 'object') {
            this.properties = properties;
        }
        else {
            this.properties = {};
        }
    }
    /**
     * Method to send a JSON response with error details.
     *
     * @param {Response} res - express response object
     */
    sendResponse(res) {
        return res.status(this.statusCode).json({
            message: this.message ?? 'Something went wrong, Please try again',
            statusCode: this.statusCode,
            ...this.properties,
        });
    }
}
exports.default = HttpException;
