"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const HttpException_1 = __importDefault(require("./HttpException"));
const http_status_1 = __importDefault(require("../utils/http-status"));
// Storing the status code and Default message for the InternalServerException
const statusCode = http_status_1.default.INTERNAL_SERVER_ERROR;
const defaultMessage = `${statusCode} Internal Server Error`;
/**
 * Custom exception class for representing internal server errors.
 * Extends the HttpException class.
 */
class InternalServerException extends HttpException_1.default {
    /**
     * Constructor for InternalServerException.
     * @param {string} message - The error message. Defaults to defaultMessage if not provided.
     * @param {object} properties - Additional properties to be attached to the exception.
     */
    constructor(message = defaultMessage, properties) {
        // Call the constructor of the parent class (HttpException)
        super(statusCode, message, properties);
        // Set the name of the exception
        this.name = 'InternalServerException';
    }
}
exports.default = InternalServerException;
