"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const HttpException_1 = __importDefault(require("./HttpException"));
const http_status_1 = __importDefault(require("../utils/http-status"));
// Storing the status code and Default message for the NotAcceptableException
const statusCode = http_status_1.default.NOT_ACCEPTABLE;
const defaultMessage = `${statusCode} Not Acceptable`;
/**
 * `NotAcceptableException` class represents an HTTP exception with a status code of 406 Not Acceptable.
 * It extends the `HttpException` class.
 */
class NotAcceptableException extends HttpException_1.default {
    /**
     * Constructor for `NotAcceptableException` class.
     *
     * @param {string} message - The error message associated with the exception. Defaults to a generic message.
     * @param {object} properties - Additional properties that can be attached to the exception.
     */
    constructor(message = defaultMessage, properties) {
        // Call the constructor of the parent class `HttpException` with appropriate parameters.
        super(statusCode, message, properties);
        // Set the name of the exception for better identification.
        this.name = 'NotAcceptableException';
    }
}
exports.default = NotAcceptableException;
