"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const HttpException_1 = __importDefault(require("./HttpException"));
const http_status_1 = __importDefault(require("../utils/http-status"));
// Storing the status code and Default message for the PayloadTooLargeException
const statusCode = http_status_1.default.PAYLOAD_TOO_LARGE;
const defaultMessage = `${statusCode} Payload too large`;
/**
 * Custom exception class for handling HTTP 413 Payload Too Large errors.
 * Extends the base HttpException class.
 */
class PayloadTooLargeException extends HttpException_1.default {
    /**
     * Constructor for PayloadTooLargeException.
     *
     * @param message - Optional. Custom error message for the exception. Defaults to a standard message.
     * @param properties - Optional. Additional properties to attach to the exception.
     */
    constructor(message = defaultMessage, properties) {
        // Call the constructor of the parent class (HttpException)
        super(statusCode, message, properties);
        // Set the name of the exception for identification
        this.name = 'PayloadTooLargeException';
    }
}
exports.default = PayloadTooLargeException;
