"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const HttpException_1 = __importDefault(require("./HttpException"));
const http_status_1 = __importDefault(require("../utils/http-status"));
// Storing the status code and Default message for the RequestTimeoutException
const statusCode = http_status_1.default.REQUEST_TIMEOUT;
const defaultMessage = `${statusCode} Request timeout`;
/**
 * RequestTimeoutException class represents an exception for HTTP request timeouts.
 * It extends the HttpException class to handle HTTP-related exceptions.
 */
class RequestTimeoutException extends HttpException_1.default {
    /**
     * Constructor for the RequestTimeoutException class.
     * @param message The error message for the exception. Defaults to defaultMessage.
     * @param properties Additional properties to include in the exception. Optional.
     */
    constructor(message = defaultMessage, properties) {
        // Call the constructor of the parent class (HttpException) with appropriate parameters.
        super(statusCode, message, properties);
        // Set the name of the exception for identification purposes.
        this.name = 'RequestTimeoutException';
    }
}
exports.default = RequestTimeoutException;
