"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const HttpException_1 = __importDefault(require("./HttpException"));
const http_status_1 = __importDefault(require("../utils/http-status"));
// Storing the status code and Default message for the UnprocessableEntityException
const statusCode = http_status_1.default.UNSUPPORTED_MEDIA_TYPE;
const defaultMessage = `${statusCode} Unsupported media type`;
/**
 * Custom exception class for representing Unsupported Media Type errors.
 * Extends the base HttpException class.
 */
class UnsupportedMediaTypeException extends HttpException_1.default {
    /**
     * Constructor for the UnsupportedMediaTypeException class.
     *
     * @param message - Optional. Custom error message. Defaults to 'Unprocessable Entity'.
     * @param properties - Optional. Additional properties to include in the error response.
     */
    constructor(message = defaultMessage, properties) {
        // Call the constructor of the base class (HttpException) with appropriate parameters
        super(statusCode, message, properties);
        // Set the name of the exception for identification
        this.name = 'UnsupportedMediaTypeException';
    }
}
exports.default = UnsupportedMediaTypeException;
