"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const HttpException_1 = __importDefault(require("../exceptions/HttpException"));
/**
 * Middleware function to handle errors and send appropriate responses.
 *
 * @param error - The HttpException representing the error that occurred.
 * @param _ - Express Request object (unused in this middleware).
 * @param res - Express Response object for sending HTTP responses.
 * @param next - Express NextFunction for passing control to the next middleware.
 */
function errorMiddleware(error, _, res, next) {
    // Log the error to the console for debugging purposes.
    console.error(error);
    // Check if the error is an instance of HttpException and send a custom response.
    if (error instanceof HttpException_1.default) {
        return error.sendResponse(res);
    }
    // If the error is not an instance of HttpException, send a generic 500 Internal Server Error response.
    return res.status(500).json({
        // @ts-ignore: Ignore TypeScript error due to potential undefined property.
        message: error?.message || 'Unknown error has occurred, Please try again.',
        statusCode: 500
    });
}
exports.default = errorMiddleware;
